@@ -7,18 +7,29 @@
 #
 #    as.im()
 #
-as.im <- function(X, W=as.mask(as.owin(X), dimyx=dimyx), ..., dimyx=NULL) {
+as.im <- function(X, W=as.mask(as.owin(X), dimyx=dimyx), ...,
+                  dimyx=NULL, na.replace=NULL) {
 
+  na.handle <- function(X, na.replace) {
+    if(is.null(na.replace))
+      return(X)
+    if(length(na.replace) != 1)
+      stop("na.replace should be a single value")
+    X$v[is.na(X$v)] <- na.replace
+    return(X)
+  }
+  
   if(verifyclass(X, "im", fatal=FALSE)) {
     if(missing(W) && is.null(dimyx))
-      return(X)
+      return(na.handle(X, na.replace))
+
     # reshape pixel raster
     # invoke W = as.mask(X, dimyx)
     Y <- as.im(W, dimyx=dimyx)
     phase <- c((Y$xcol[1] - X$xcol[1])/X$xstep,
                (Y$yrow[1] - X$yrow[1])/X$ystep)
     Y$v <- matrixsample(X$v, Y$dim, phase=round(phase))
-    return(Y)
+    return(na.handle(Y, na.replace))
   }
 
   if(verifyclass(X, "owin", fatal=FALSE)) {
@@ -44,7 +55,7 @@ as.im <- function(X, W=as.mask(as.owin(X), dimyx=dimyx), ..., dimyx=NULL) {
                 type    = "integer",
                 units  = units(X))
     class(out) <- "im"
-    return(out)
+    return(na.handle(out, na.replace))
   }
 
   if((is.vector(X) || is.factor(X)) && length(X) == 1) {
@@ -76,7 +87,8 @@ as.im <- function(X, W=as.mask(as.owin(X), dimyx=dimyx), ..., dimyx=NULL) {
     if(is.factor(values)) 
         lev <- levels(values)
 
-    return(im(values, W$xcol, W$yrow, lev, units=units(W)))
+    out <- im(values, W$xcol, W$yrow, lev, units=units(W))
+    return(na.handle(out, na.replace))
   }
 
   if(is.list(X) && checkfields(X, c("x","y","z"))) {
@@ -101,12 +113,11 @@ as.im <- function(X, W=as.mask(as.owin(X), dimyx=dimyx), ..., dimyx=NULL) {
     # convert to class "im"
     out <- im(t(z), x, y)
     # now apply W and dimyx if present
-    if(missing(W) && is.null(dimyx))
-      return(out)
-    else if(missing(W))
-      return(as.im(out, dimyx=dimyx))
-    else
-      return(as.im(out, W=W, dimyx=dimyx))
+    if(missing(W) && !is.null(dimyx))
+      out <- as.im(out, dimyx=dimyx)
+    else if(!missing(W))
+      out <- as.im(out, W=W, dimyx=dimyx)
+    return(na.handle(out, na.replace))
   }
     
   stop("Can't convert X to a pixel image")
